# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-PlRPC 
Version:	0.2020 
Release:	16.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
Summary:	Interface for writing PlRPC clients and servers
URL:		http://search.cpan.org/dist/PlRPC
Source0:	http://search.cpan.org/CPAN/authors/id/M/MN/MNOONING/PlRPC/PlRPC-%{version}.tar.gz 
Patch0:		PlRPC-0.2020-Do-not-use-syslog.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Pod::Perldoc)
# Module Runtime
BuildRequires:	perl(Compress::Zlib)
BuildRequires:	perl(IO::Socket)
BuildRequires:	perl(Net::Daemon) >= 0.13
BuildRequires:	perl(Net::Daemon::Log)
BuildRequires:	perl(Net::Daemon::Test)
BuildRequires:	perl(Storable)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(Crypt::DES)
BuildRequires:	perl(lib)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Compress::Zlib)
Requires:	perl(Net::Daemon) >= 0.13

%description
PlRPC (Perl RPC) is a package that simplifies the writing of Perl based
client/server applications. RPC::PlServer is the package used on the
server side, and you guess what RPC::PlClient is for. PlRPC works by 
defining a set of methods that may be executed by the client.

%prep
%setup -q -n PlRPC

# Don't use syslog in tests
# See <https://rt.cpan.org/Public/Bug/Display.html?id=74430>
%patch -P 0 -p 1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc ChangeLog README 
%{perl_vendorlib}/Bundle/
%{perl_vendorlib}/RPC/
%{_mandir}/man3/Bundle::PlRPC.3*
%{_mandir}/man3/RPC::PlClient.3*
%{_mandir}/man3/RPC::PlServer.3*

%changelog
* Thu Sep 21 2023 Paul Howarth <paul@city-fan.org> - 0.2020-16
- Avoid use of deprecated patch syntax

* Tue Jan 24 2023 Paul Howarth <paul@city-fan.org> - 0.2020-15
- Use SPDX-format license tag

* Tue Apr 17 2018 Paul Howarth <paul@city-fan.org> - 0.2020-14
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Wed Sep 21 2016 Paul Howarth <paul@city-fan.org> - 0.2020-13
- Classify buildreqs by usage
- Simplify find command using -delete

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 0.2020-12
- Drop %%defattr, redundant since rpm 4.4

* Sat Jun 23 2012 Paul Howarth <paul@city-fan.org> - 0.2020-11
- BR: perl(lib)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - BR: perl(Crypt::DES) unconditionally
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Jan 30 2012 Paul Howarth <paul@city-fan.org> - 0.2020-10
- Import from Fedora

* Thu Jan 26 2012 Petr Pisar <ppisar@redhat.com> - 0.2020-9
- Modernize spec file
- Enable tests

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2020-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Jun 20 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.2020-7
- Perl mass rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2020-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.2020-5
- Rebuild to fix problems with vendorarch/lib (#661697)

* Tue May 04 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.2020-4
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.2020-3
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2020-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Apr 01 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.2020-1
- Submission

* Thu Mar 19 2009 Chris Weyl <cweyl@alumni.drew.edu> - 0.2020-0
- Initial RPM packaging
- Generated with cpan2dist (CPANPLUS::Dist::RPM version 0.0.8)

